Ctx

Struct Ctx 

pub struct Ctx<'a> {
    pub orig: Args,
    pub args: Vec<&'a OsStr>,
    pub inner_ctx: Option<InnerCtx<'a>>,
    /* private fields */
}
The invoke context of option handler. It saved the option information and matched arguments.

Fields

orig: Argsargs: Vec<&'a OsStr>inner_ctx: Option<InnerCtx<'a>>

Implementations

Source

impl<'a> Ctx<'a>

pub fn with_args(self, args: Vec<&'a OsStr>) -> Self

pub fn with_orig(self, orig_args: Args) -> Self

pub fn with_inner_ctx(self, inner_ctx: InnerCtx<'a>) -> Self

Source

impl<'a> Ctx<'a>

pub fn uid(&self) -> Result<Uid, Error>

The uid of matched option.

pub fn idx(&self) -> Result<usize, Error>

The index of matched option.

pub fn total(&self) -> Result<usize, Error>

The total number of arguments.

pub fn name(&self) -> Result<Option<&Cow<'a, str>>, Error>

The name of matched option. For option it is the option name, for NOA it is the argument, which set in invoke.

pub fn style(&self) -> Result<Style, Error>

The style of matched option.

pub fn args(&self) -> &[&'a OsStr]

The copy of Args when the option matched. It may be changing during parsing process.

pub fn arg(&self) -> Result<Option<&Cow<'a, OsStr>>, Error>

The argument which set in invoke.

pub fn inner_ctx(&self) -> Result<&InnerCtx<'a>, Error>

pub fn inner_ctx_mut(&mut self) -> Result<&mut InnerCtx<'a>, Error>

pub fn orig(&self) -> &Args

The original arguments passed by user.

pub fn arg_at(&self, idx: usize) -> Result<Option<&'a OsStr>, Error>

The current argument indexed by self.idx().

pub fn take_args(&mut self) -> Vec<&OsStr>

pub fn take_orig_args(&mut self) -> Args

Source

impl<'a> Ctx<'a>

pub fn set_uid(&mut self, uid: Uid) -> Result<&mut Self, Error>

pub fn set_index(&mut self, index: usize) -> Result<&mut Self, Error>

The index of matching context.

pub fn set_total(&mut self, total: usize) -> Result<&mut Self, Error>

The total of matching context.

pub fn set_args(&mut self, args: Vec<&'a OsStr>) -> &mut Self

pub fn set_name( &mut self, name: Option<Cow<'a, str>>, ) -> Result<&mut Self, Error>

pub fn set_style(&mut self, style: Style) -> Result<&mut Self, Error>

pub fn set_arg( &mut self, arg: Option<Cow<'a, OsStr>>, ) -> Result<&mut Self, Error>

pub fn set_orig_args(&mut self, orig_args: Args) -> &mut Self

pub fn set_inner_ctx(&mut self, inner_ctx: Option<InnerCtx<'a>>) -> &mut Self

Source

impl Ctx<'_>

pub fn policy_act(&self) -> Action

pub fn set_policy_act(&self, act: Action)

pub fn reset_policy_act(&self)

Source

impl Ctx<'_>

pub fn value<T: RawValParser>(&self) -> Result<T, Error>