AnyValue

Struct AnyValue 

pub struct AnyValue(/* private fields */);
AnyValue can save values of any type. In internal it save the value into a vector of type T.

Example

let mut value = AnyValue::new();

assert_eq!(value.contain_type::<i32>(), false);
assert_eq!(value.set(vec![42]), None);
assert_eq!(value.contain_type::<i32>(), true);

assert_eq!(value.val::<i32>()?, &42);
assert_eq!(value.push(256).val::<i32>()?, &256);
value.val_mut::<i32>()?.sub_assign(128);
assert_eq!(value.val::<i32>()?, &128);

assert_eq!(value.vals::<i32>()?, &vec![42, 128]);
assert_eq!(value.pop::<i32>(), Some(128));
assert_eq!(value.vals::<i32>()?, &vec![42]);

value.entry::<u64>().or_insert(vec![9, 0, 2, 5]);
assert_eq!(value.entry::<u64>().or_default().pop(), Some(5));

value.vals_mut::<i32>()?.pop();
assert_eq!(value.vals::<i32>()?.len(), 0);

assert_eq!(value.remove::<u64>(), Some(vec![9, 0, 2]));
assert_eq!(value.contain_type::<u64>(), false);

Implementations

Source

impl AnyValue

pub fn new() -> Self

pub fn clear(&mut self)

pub fn contain_type<T: ErasedTy>(&self) -> bool

pub fn pop<T: ErasedTy>(&mut self) -> Option<T>

pub fn entry<T: ErasedTy>(&mut self) -> Entry<'_, Vec<T>>

pub fn push<T: ErasedTy>(&mut self, val: T) -> &mut Self

Push a value to the values of type T.

pub fn set<T: ErasedTy>(&mut self, vals: Vec<T>) -> Option<Vec<T>>

Set the values of type T.

pub fn remove<T: ErasedTy>(&mut self) -> Option<Vec<T>>

Remove the values of type T.

pub fn val<T: ErasedTy>(&self) -> Result<&T, Error>

Get the last value reference of type T.

pub fn val_mut<T: ErasedTy>(&mut self) -> Result<&mut T, Error>

Get the last value mutable reference of type T.

pub fn vals<T: ErasedTy>(&self) -> Result<&Vec<T>, Error>

Get the values of type T.

pub fn vals_mut<T: ErasedTy>(&mut self) -> Result<&mut Vec<T>, Error>

Get the values of type T.